@@ -36,8 +36,6 @@ Do not instantiate these classes directly, but rather use them through TvpProfil
 """
 
 import os
-from subprocess import Popen, PIPE
-
 from tvb.basic.config import stored
 
 
@@ -47,7 +45,7 @@ class VersionSettings(object):
     """
 
     # Current release number
-    BASE_VERSION = "2.0.5"
+    BASE_VERSION = "2.0.8"
 
     # Current DB version. Increment this and create a new xxx_update_db.py migrate script
     DB_STRUCTURE_VERSION = 18
@@ -80,17 +78,6 @@ class VersionSettings(object):
 
     @property
     def SVN_VERSION(self):
-        """Current SVN version in the package running now."""
-        svn_variable = 'SVN_REVISION'
-        if svn_variable in os.environ:
-            return os.environ[svn_variable]
-
-        try:
-            _proc = Popen(["svnversion", "."], stdout=PIPE, stderr=PIPE)
-            return self.parse_svn_version(_proc.communicate()[0])
-        except Exception:
-            pass
-
         try:
             import tvb.basic.config
             config_folder = os.path.dirname(os.path.abspath(tvb.basic.config.__file__))
@@ -99,7 +86,7 @@ class VersionSettings(object):
         except Exception:
             pass
 
-        raise ValueError('cannot determine TVB revision number')
+        return 42
 
     @staticmethod
     def parse_svn_version(version_string):
@@ -197,12 +184,39 @@ class ClusterSettings(object):
         return None
 
 
+class HPCSettings(object):
+    """
+    HPC related specifications
+    """
+    HPC_LAUNCHER_SH_SCRIPT = "hpcLauncher"
+
+    UNICORE_RESOURCER_KEY = 'Resources'
+    UNICORE_ARGS_KEY = 'Arguments'
+    UNICORE_EXE_KEY = 'Executable'
+
+    JOB_STATUS_KEY = 'status'
+    JOB_MOUNT_POINT_KEY = 'mountPoint'
+
+    CRYPT_BUFFER_SIZE = 64 * 1024
+    CRYPT_PASS_SIZE = 64
+
+    # Specify if the current process is executing an operation (via hpcLauncher)
+    IN_OPERATION_EXECUTION_PROCESS = False
+
+    def __init__(self, manager):
+        self.IS_HPC_RUN = manager.get_attribute(stored.KEY_HPC, False, eval)
+        self.BACKGROUND_JOB_INTERVAL = manager.get_attribute(stored.KEY_HPC_INTERVAL, 60, int)
+        self.HPC_COMPUTE_SITE = manager.get_attribute(stored.KEY_HPC_COMPUTE_SITE)
+        self.CRYPT_DATADIR = manager.get_attribute(stored.KEY_CRYPT_DATADIR)
+        self.CRYPT_PASSDIR = manager.get_attribute(stored.KEY_CRYPT_PASSDIR)
+
+
 class WebSettings(object):
     """
     Web related specifications
     """
 
-    LOCALHOST = "127.0.0.1"
+    LOCALHOST = "localhost"
     RENDER_HTML = True
     VISUALIZERS_ROOT = "tvb.interfaces.web.templates.jinja2.visualizers"
 
@@ -293,6 +307,9 @@ class WebAdminSettings(object):
         # Admin's email used when creating first user
         self.ADMINISTRATOR_EMAIL = manager.get_attribute(stored.KEY_ADMIN_EMAIL, self.DEFAULT_ADMIN_EMAIL)
 
+        # Admins GID
+        self.ADMINISTRATOR_GIDS = manager.get_attribute(stored.KEY_ADMIN_GIDS, "").split(",")
+
 
 class DBSettings(object):
     # Overwrite number of connections to the DB.
